@@ -69,7 +69,7 @@ class SNSserverException(Exception):
         message -- explanation of the error
     """
 
-    def __init__(self, message="Exception occurred while performing an operation on an SNS object"):
+    def __init__(self, message="Exception occurred while an operation was performed on the server"):
         self.message = message
         super().__init__(self.message)
 
