@@ -7,13 +7,7 @@ def parse(interaction):
     """
     Parses a string representing a interaction made with the SNS protocol.
     """
-    try:
-        interaction = interaction.decode('utf-8')
-        raise AttributeError()
-    except AttributeError:
-        interaction.replace('\r\n', '\n')
-
-    interaction_lines = interaction.split('\n\n')
+    interaction_lines = re.split(r"(?:\r?\n){2,}", interaction)
     headers = interaction_lines[0].splitlines()
 
     if len(interaction_lines) > 2:
@@ -75,20 +69,6 @@ def parse(interaction):
 
     _interaction_content = None
     if len(interaction_lines) == 2 and len(interaction_lines[1]) > 0:
-        _interaction_content = parse_content(interaction_lines[1])
+        _interaction_content = interaction_lines[1]
 
-    return SNSinteraction(_interaction_type, _interaction_action, _interaction_headers, _interaction_content)
-
-def parse_content(content):
-    try:
-        content_parameters = content.splitlines()
-        _interaction_content = {}
-
-        for content_parameter in content_parameters:
-            param_type, param_value = content_parameter.split(": ")
-
-            _interaction_content[param_type] = param_value
-    except:
-        _interaction_content = content
-
-    return _interaction_content
\ No newline at end of file
+    return SNSinteraction(_interaction_type, _interaction_action, _interaction_headers, _interaction_content)
\ No newline at end of file
